
.. raw:: html

   <embed>
   <h1 style="letter-spacing: 0.4em; font-size: 2.5em !important;
   margin-bottom: 0; padding-bottom: 0"> AMS </h1>

   <p style="color: #00746F; font-variant: small-caps; font-weight: bold;
   margin-bottom: 2em">
   Python Library for Flexible Scheduling Modeling and Co-Simulation with Dynamics</p>
   </embed>

.. _getting-started:

===============
Getting started
===============

.. toctree::
    :maxdepth: 3
    :hidden:

    overview
    install
    formats/index
    testcase
    verification
    copyright

Quick install
=============

.. panels::
    :card: + install-card
    :column: col-lg-6 col-md-6 col-sm-12 col-xs-12 p-3

    Working with conda?
    ^^^^^^^^^^^^^^^^^^^
    AMS will available on conda-forge and can be installed with
    Anaconda, Miniconda, and Mambaforge:

    ++++++++++++++++++++++

    .. code-block:: bash

        conda install -c conda-forge ltbams

    ---

    Prefer pip?
    ^^^^^^^^^^^

    AMS will be installed via pip from `PyPI <https://pypi.org/project/ltbams>`__.

    ++++

    .. code-block:: bash

        pip install ltbams

    ---
    :column: col-12 p-3

    New to Python?
    ^^^^^^^^^^^^^^
    Set up a Mambaforge environment following :ref:`Setup Mambaforge`. We
    recommend Mambaforge on Windows and Apple Silicon for new users.

    ---
    :column: col-12 p-3

    Are you a developer?
    ^^^^^^^^^^^^^^^^^^^^

    Installing from source? Looking to develop models? Check the
    guide in :ref:`Develop Install`.